
# Required Variables

variable "tags" {
  type        = map(string)
  description = "The URL to the Gitlab repository where the code resides"
}

variable "cloudfront_name" {
  type        = string
  description = "Name to attach to the comments section of the Cloudfront CDN"
}

variable "origin_access_id" {
  type        = string
  description = "The ARN of the Origin Access Identity to use with this distribution"
}

variable "price_class" {
  type        = string
  description = "The price class for this distribution"
}

variable "http_version" {
  type        = string
  description = "The maximum HTTP version to support on the distribution"
}

variable "enable_distribution" {
  type        = bool
  description = "Whether the distribution is enabled to accept end user requests for content"
}

variable "enable_ipv6" {
  type        = bool
  description = "Whether IPv6 is enabled for the distribution"
}

variable "retain_on_delete" {
  type        = bool
  description = "Disables the distribution instead of deleting it when destroying the resource through Terraform. If this is set, the distribution needs to be deleted manually afterwards"
}

variable "wait_for_deployment" {
  type        = bool
  description = "If enabled, the resource will wait for the distribution status to change from InProgress to Deployed. Setting this to false will skip the process"
}

variable "logging_includes_cookies" {
  type        = bool
  description = "Logging, if the logs should save cookies"
}

variable "logging_prefix" {
  type        = string
  description = "Logging, prefix for the s3 path"
}

variable "geo_restriction_type" {
  type        = string
  description = "The method that you want to use to restrict distribution of your content by country: none, whitelist, or blacklist"
}

variable "geo_restriction_locations" {
  type        = list(string)
  description = "The ISO 3166-1-alpha-2 codes for which you want CloudFront either to distribute or not distribute your content"
}

variable "default_bucket_arn" {
  type        = string
  description = "ARN of the s3 bucket to use as the default cache behavior for Cloudfront"
}

variable "default_bucket_domain_name" {
  type        = string
  description = "Domain name of the s3 bucket to use as the default cache behavior for Cloudfront"
}

variable "logging_bucket_domain_name" {
  type        = string
  description = "Domain name of the s3 bucket to use as the logging bucket for Cloudfront"
}

variable "default_cache_behavior" {
  type = object({
    origin_id              = string,
    viewer_protocol_policy = string,
    allowed_methods        = any,
    cached_methods         = any,
    min_ttl                = number,
    default_ttl            = number,
    max_ttl                = number,
    fwd_query_string       = bool,
    fwd_headers            = any,
    fwd_cookies            = string,
    enable_compress        = bool,
    enable_signing         = bool,
    enable_lambda          = bool,
    event_type             = string,
    include_body           = bool,
  })
  description = "Default cache (precedence 0) behavior"
}

variable "cache_behaviors" {
  type = map(object({
    origin_id              = string,
    path_pattern           = string,
    viewer_protocol_policy = string,
    allowed_methods        = any,
    cached_methods         = any,
    min_ttl                = number,
    default_ttl            = number,
    max_ttl                = number,
    fwd_query_string       = bool,
    fwd_headers            = any,
    fwd_cookies            = string,
    enable_compress        = bool,
    enable_signing         = bool,
    enable_lambda          = bool,
    event_type             = string,
    include_body           = bool,
  }))
  description = "Additional cache behaviors"
}

# Defaulted Variables

variable "oai_regex_pattern" {
  type        = string
  description = "Regex for matching on the Origin Access Identity"
  default     = "^arn:(aws|aws-us-gov):iam::cloudfront:user\\/CloudFront Origin Access Identity ([a-zA-Z0-9]*)$"
}

variable "s3_regex_pattern" {
  type        = string
  description = "Regex for matching on the Origin Access Identity"
  default     = "^arn:(aws|aws-us-gov):s3:::([a-zA-Z0-9-_]*)$"
}

variable "cloudfront_alias" {
  type        = list(string)
  description = "The Cloudfront domain alias to serve requests behind"
  default     = []
}

variable "cache_bucket_arns" {
  description = "Map of releaseName-PrefixName => s3 ARN to use w/ cache behaviors for Cloudfront"
  type        = map(string)
  default     = {}
}

variable "cache_bucket_regional_domains" {
  description = "Map of releaseName-PrefixName => s3 Regional Domain to use w/ cache behaviors for Cloudfront"
  type        = map(string)
  default     = {}
}

variable "cache_lambda_arns" {
  type        = map(string)
  description = "Map of releaseName-PrefixName => lambda ARN to use w/ Lambda@Edge for Cloudfront ordered caches"
  default     = {}
}

variable "public_key_ids" {
  type        = set(string)
  description = "Map of releaseName-PrefixName => Public Key ID to attach to the Key Group for Cloudfront"
  default     = []
}

// TODO: Configure this when the ACM certificate is ready
//variable "custom_viewer_certificate" {
//  type = object({
//    acm_arn                  = string,
//    ssl_support_method       = string,
//    minimum_protocol_version = string,
//  })
//  description = "Custom SSL Certificate information to assign an alias to the CDN"
//}

variable "default_cache_lambda_arn" {
  type        = string
  description = "lambda ARN to use w/ Lambda@Edge for Cloudfront default cache"
  default     = ""
}

variable "web_acl_arn" {
  type        = string
  description = "ARN that specifies the AWS WAF web ACL, if any, to associate with this distribution"
  default     = ""
}